function [D] = Clones_CompleteD(C,M)
%Clones_D Compute the complete diagram with the diagram representation
%	Clones_CompleteD(C,M) 
%           C : vector of capacities
%           M : customers number
%
%	[D] = Clones_CompleteD(C,M) 
%           D : complete diagram
%
%	See also :
%               Clones_T
%               Clones_plotD
%               Clones_Psi

% C. Rovetta
% 11.09.2014
% Version 1.0
%



K=size(C,2);

% Matrix with infinite capacity
Mat=ones(M+1,M+1);
Mat=triu(Mat);

D=zeros(M+1,K*(M+1));

% Diagram with capacity

% First matrix
mm=1;
if(C(1)>=M)
    D(1,mm:mm+M)=1;
else
    D(1,mm:mm+C(1))=1;
end

% Intermediate matrices
for k=2:K-1
    
    mm=mm+M+1;
    if(C(k)>=M)
        D(:,mm:mm+M)=Mat;
    else
        D(:,mm:mm+M)=tril(Mat,C(k));
    end
end

% Last matrix
if(C(K)>=M)
    D(:,end)=1;
else
    D(M+1-C(K):M+1,end)=1;
end

% Paths determination

% --->
vec=D(1,1:M+1);

mm=1;
for k=2:K
    mm=mm+M+1;

    Mat=D(:,mm:mm+M);
    Mat(vec==0,:)=0;
    D(:,mm:mm+M)=Mat;
    
    vec=logical(sum(Mat,1));
    
end

% <---
vec=D(:,end);

mm=(K-1)*(M+1)+1;
for k=K-1:-1:1
    
    mm=mm-(M+1);
    
    Mat=D(:,mm:mm+M);
    Mat(:,vec==0)=0;
    D(:,mm:mm+M)=Mat;
    
    vec=logical(sum(Mat,2));
    
end



























