function [D] = Clones_T(D,C,r)
%Clones_T Transition i->j on the diagram
%	Clones_T(S,C,r)
%           D : diagram representation
%           C : vector of capacities
%           r : r=[i j] transition
%
%	[D] = Clones_T(K,M) 
%           D : transition of the diagram
%
%	See also :
%               Clones_D

% C. Rovetta
% 11.09.2014
% Version 1.0
%

i=r(1);
j=r(2);

MM=size(D,1);
M=MM-1;

if(i<j)
    
    nbM=(j-i+1);
    nbMm=nbM*MM;
    
    % Step 1 : subset determination
    
    Empty=zeros(MM,nbMm);
    NEmpty=zeros(MM,nbMm);
    Full=zeros(MM,nbMm);
    NFull=ones(MM,nbMm);
    
    % Empty, Non Empty --->
    
    mm=(i-1)*MM+1;
    mc=1;
    
    Mat=D(:,mm:mm+M);
    
    Ec=tril(Mat);
    Empty(:,mc:mc+M)=Ec;
    vE=logical(sum(Ec,1));
    
    NEc=Mat-Ec;
    NEmpty(:,mc:mc+M)=NEc;
    vNE=logical(sum(NEc,1));
   
    for c=2:nbM
        
        mm=mm+MM;
        mc=mc+MM;
        
        Mat=D(:,mm:mm+M);
        Ec=Mat;
        NEc=Mat;
        
        Ec(vE==0,:)=0;
        NEc(vNE==0,:)=0;
        
        Empty(:,mc:mc+M)=Ec;
        NEmpty(:,mc:mc+M)=NEc;
        
        vE=logical(sum(Ec,1));
        vNE=logical(sum(NEc,1));
        
      
        
    end
    
    % Full, Non Full --->
    if(C(j)<M)
        
        mm=(j-1)*MM+1;
        mc=(nbM-1)*MM+1;
        
        Mat=D(:,mm:mm+M);
        
        if(sum(diag(Mat,C(j)))>0)
            
            Fc=triu(Mat,C(j));
            Full(:,mc:mc+M)=Fc;
            vF=logical(sum(Fc,2));
    
            NFc=Mat-Fc;
            NFull(:,mc:mc+M)=NFc;
            vNF=logical(sum(NFc,2));
            
            for c=2:nbM
                mm=mm-MM;
                mc=mc-MM;
        
                Mat=D(:,mm:mm+M);
        
                Fc=Mat;
                NFc=Mat;
        
                Fc(:,vF==0)=0;
                NFc(:,vNF==0)=0;
        
                Full(:,mc:mc+M)=Fc;
                NFull(:,mc:mc+M)=NFc;
        
                vF=logical(sum(Fc,2));
                vNF=logical(sum(NFc,2));
        
            end
            
        end
        
    end
    
    Stay=logical(Empty+Full);
    Transit=NEmpty&NFull;

    % Step 2 : compute Transit '

    % Departure in i
    mc=1;
    
    Transit(:,mc:mc+M-1)=Transit(:,mc+1:mc+M);
    Transit(:,mc+M)=zeros(MM,1);
    
     % Intermediate matrices
    for c=2:nbM-1
        mc=mc+MM;
        
        Transit(:,mc:mc+M-1)=Transit(:,mc+1:mc+M);
        Transit(:,mc+M)=zeros(MM,1);
        
        Transit(1:M,mc:mc+M)=Transit(2:MM,mc:mc+M);
        Transit(MM,mc:mc+M)=zeros(1,MM);
    end
   

    % Arrival in j
    mc=mc+MM;
    Transit(1:M,mc:mc+M)=Transit(2:MM,mc:mc+M);
    Transit(MM,mc:mc+M)=zeros(1,MM);
    
    % Step 3 : compute A '
    mmb=((i-1)*MM)+1;
    mme=j*MM;
    
    D(:,mmb:mme)=logical(Stay+Transit);
    
end

 
if(i>j)
     
    nbM=(i-j+1);
    nbMm=nbM*MM;
    
    % Step 1 : subset determination
    
    Empty=zeros(MM,nbMm);
    NEmpty=zeros(MM,nbMm);
    Full=zeros(MM,nbMm);
    NFull=ones(MM,nbMm);
    
    
    
    % Empty, Non Empty --->
    
    mm=(i-1)*MM+1;
    mc=(nbM-1)*MM+1;
    
    Mat=D(:,mm:mm+M);
    
    Ec=tril(Mat);
    Empty(:,mc:mc+M)=Ec;
    vE=logical(sum(Ec,2));
    
    NEc=Mat-Ec;
    NEmpty(:,mc:mc+M)=NEc;
    vNE=logical(sum(NEc,2));
   
    for c=2:nbM
        
        mm=mm-MM;
        mc=mc-MM;
        
        Mat=D(:,mm:mm+M);
        Ec=Mat;
        NEc=Mat;
        
        Ec(:,vE==0)=0;
        NEc(:,vNE==0)=0;
        
        Empty(:,mc:mc+M)=Ec;
        NEmpty(:,mc:mc+M)=NEc;
        
        vE=logical(sum(Ec,2));
        vNE=logical(sum(NEc,2));
        
    end
    
    
    % Full, Non Full --->
    if(C(j)<M)
        
        mm=(j-1)*MM+1;
        mc=1;
        
        Mat=D(:,mm:mm+M);
        
        if(sum(diag(Mat,C(j)))>0)
            
            Fc=triu(Mat,C(j));
            Full(:,mc:mc+M)=Fc;
            vF=logical(sum(Fc,1));
    
            NFc=Mat-Fc;
            NFull(:,mc:mc+M)=NFc;
            vNF=logical(sum(NFc,1));
            
            for c=2:nbM
                mm=mm+MM;
                mc=mc+MM;
        
                Mat=D(:,mm:mm+M);
        
                Fc=Mat;
                NFc=Mat;
        
                Fc(vF==0,:)=0;
                NFc(vNF==0,:)=0;
        
                Full(:,mc:mc+M)=Fc;
                NFull(:,mc:mc+M)=NFc;
        
                vF=logical(sum(Fc,1));
                vNF=logical(sum(NFc,1));
        
            end
            
        end
        
    end
    
    Stay=logical(Empty+Full);
    Transit=NEmpty&NFull;

    % Step 2 : compute Transit '

    % Departure in i
    mc=(nbM-1)*MM+1;
    
    Transit(2:MM,mc:mc+M)=Transit(1:M,mc:mc+M);
    Transit(1,mc:mc+M)=zeros(1,MM);
    
     % Intermediate matrices
    for c=2:nbM-1
        
        mc=mc-MM;
        
        Transit(2:MM,mc:mc+M)=Transit(1:M,mc:mc+M);
        Transit(1,mc:mc+M)=zeros(1,MM);
        
        Transit(:,mc+1:mc+M)=Transit(:,mc:mc+M-1); 
        Transit(:,mc)=zeros(MM,1);
    end
   

    % Arrival in j
    mc=mc-MM;
    
    Transit(:,mc+1:mc+M)=Transit(:,mc:mc+M-1);
    Transit(:,mc)=zeros(MM,1);
    
    % Step 3 : compute A '
    mmb=((j-1)*MM)+1;
    mme=i*MM;
    
    D(:,mmb:mme)=logical(Stay+Transit);
    
    
end




end

