function [mov] = Clones_plotD(D,C,mode)
%Clones_plotD Plot the diagram
%	Clones_plotD(D,C,mode) 
%           D : diagram representation
%           C : capacities vector
%           mode : 
%               mode > 0    print n=mode
%               mode=-1     print parameters and Psi(D)
%               mode=-2     print Psi(D)
%               else        don't print legend
%
%	[mov] = Clones_plotD(D) 
%           mov : matrix to make movie
%
%	See also :
%               Clones_D
%               Clones_CardPsi

% C. Rovetta
% 11.09.2014
% Version 1.0
%

close all;

[MM kk]=size(D);

K=kk/MM;
M=MM-1;


if mode==-1
    if(K<35)
        cardS=Clones_CardPsi(D);
        text(-1,1,['K= ',num2str(K),'   M=',num2str(M), '   C=',mat2str(C)]);
        if(cardS~=-1)
            text(-1,-MM,['|Psi(D)| = ',num2str(cardS)]);
        end
    else
        text(-1,1,['K: ',num2str(K),'  M=',num2str(M)]);
    end
end

if mode==-2
    cardS=Clones_CardPsi(D);
    if cardS==-1
        text(-1,-MM,'|Psi(D)| is too large ');
    else
        text(-1,-MM,['|Psi(D)| = ',num2str(cardS)]);
    end
end

if mode>=0
    cardS=Clones_CardPsi(D);
    
    text(-1,-MM+1,['n= ',num2str(mode)]);
    
    if cardS==-1
        text(-1,-MM,'|Psi(D)| is too large ');
    else
        text(-1,-MM,['|Psi(D)| = ',num2str(cardS)]);
    end
end

%PLOT Diagram
axis([-2 (K+2) -MM-1 2]);

Yc=-ones(MM,MM);
Yc=cumsum(Yc);
Yc=Yc';
Yc=Yc(:);

y=0:-1:-M;

Poko=triu((-ones(MM,MM))+diag(y));
Poko=cumsum(Poko,2);


hold on;
mm=1;
for k=1:K
    
    Xk=[k-1, k];
    
    Mat=D(:,mm:mm+M);
    Mask=Poko;
    
    Mask(Mat==0)=0;
    Mask=Mask';
    Mask=Mask(:);
    
    Yk=[Yc,Mask];
    Yk(Mask==0,:)=[];
    
    Yk=Yk+ones(size(Yk));
    
    if(size(Yk,1)==2)
        plot(Xk,Yk(1,:),'b-o','MarkerSize',8,'MarkerFaceColor',[.9 .9 .9]);
        plot(Xk,Yk(2,:),'b-o','MarkerSize',8,'MarkerFaceColor',[.9 .9 .9]);
        
    else
        plot(Xk,Yk,'b-o','MarkerSize',8,'MarkerFaceColor',[.9 .9 .9]);
    end
    
    mm=mm+MM;
end

mov=getframe;

hold off;



end