function [F] = Clones_CompleteF(C,M)
%Clones_CompleteF Compute complete diagram with the gap-free representation
%	Clones_CompleteF(C,M) 
%           M : customers number
%           C : vector of capacities
%
%	[F] = Clones_S(C,M) 
%           F : gap-free diagram
%
%	See also :
%               Clones_CompleteD(C,M)

% C. Rovetta
% 25.09.2014
% Version 1.0
%

K=size(C,2);

CC=ones(K,1)+C';
CC=cumsum(CC);

MM=M:-1:0;
MM=MM';

% ======> Matrices determination

F=-ones(sum(C,2)+K,2);

% First matrix
F(1:CC(1),:)=zeros(C(1)+1,2);

% Intermediate matrices
for k=2:K-1
    F(CC(k-1)+1:CC(k),:)=[zeros(C(k)+1,1) MM(1:C(k)+1,1)];
end

% Last matrix
F(CC(K-1)+1:CC(K),:)=[(M:-1:M-C(K))',(M:-1:M-C(K))'];


% ======> Paths determination

% --->

vM=(0:M)';

% First matrix vector
debut=0;
fin=C(1);

for k=2:K

    X=F(CC(k-1)+1:CC(k),:);
    vnc=(X(:,1)==-1);
    
    X(:,1)=max(X(:,1),debut);
    X(:,2)=min(X(:,2),fin);
    X(vnc,:)=-1;
    
    vnc=(X(:,1)>X(:,2));
    X(vnc,:)=-1;

    F(CC(k-1)+1:CC(k),:)=X;

    % Find min-max for the next matrix
    vnc=(X(:,1)==-1);

    vMk=vM(1:C(k)+1);
    vMk=repmat(vMk,1,2);
    X=X+vMk;
    
    X(vnc,:)=[];

    debut=min(X(:,1));
    fin=max(X(:,2));
end

% <---
debut= M-C(1);
fin=M;

for k=K-1:-1:2
    
    vMk=vM(1:C(k)+1);
    vMk=repmat(vMk,1,2);
     
    X=F(CC(k-1)+1:CC(k),:);
    vnc=(X(:,1)==-1);
    
    X=X+vMk;
    
    X(:,1)=max(X(:,1),debut);
    X(:,2)=min(X(:,2),fin);
    
    X=X-vMk;
    X(vnc,:)=-1;
    
    vnc=(X(:,1)>X(:,2));
    X(vnc,:)=-1;
    
    F(CC(k-1)+1:CC(k),:)=X;
    
    % Find min-max for the next matrix
    X(vnc,:)=[];
    debut=min(X(:,1));
    fin=max(X(:,2));
    
   
end

k=1;
 
vMk=vM(1:C(k)+1);
vMk=repmat(vMk,1,2);
X=F(1:CC(k),:);
vnc=(X(:,1)==-1);
X=X+vMk;
X(:,1)=max(X(:,1),debut);
X(:,2)=min(X(:,2),fin);
X=X-vMk;
X(vnc,:)=-1;
vnc=(X(:,1)>X(:,2));
X(vnc,:)=-1;
F(1:CC(k),:)=X;


end


