classdef Clones_F
%Clones_F Class of diagrams with gap-free representation
%           Mod: Model to consider
%           K : queues number
%           M : customers number
%           C : vector of capacities
%           F : matrix representation of diagram
%           cF : matrix representation of complete diagram
%
% C. Rovetta
% 11.09.2014
% Version 1.0
%

    
    properties
        Mod
        K
        M
        C
        F
        cF % Complete Gap-free diagram
    end
    
    methods
        function obj = Clones_F(mod)
            obj.Mod=mod;
            obj.K=mod.K;
            obj.M=mod.M;
            obj.C=mod.C;
            obj.cF=Clones_CompleteF(mod.C,mod.M);
            obj.F=obj.cF;
        end
        
        function obj=reset(obj)
            obj.F= obj.cF;
        end
        
        function obj=gfT(obj,r)
            obj.F=Clones_gfT(obj.F,obj.C,obj.M,r);
        end
        
        function obj=gfTm(obj,r)
            obj.F=Clones_gfTm(obj.F,obj.C,obj.M,r);
        end
        
        function S=Psi(obj)
            D=Clones_FtoD(obj.F,obj.C,obj.M);
            S=Clones_Psi(D);
        end
        
        function card=cardPsi(obj)
            D=Clones_FtoD(obj.F,obj.C,obj.M);
            card=Clones_CardPsi(D);
        end
        
        function mov = plot(obj,mode)
            D=Clones_FtoD(obj.F,obj.C,obj.M);
            mov = Clones_plotD(D,obj.C,mode);
        end
        
        function Diagram=FtoD(obj)
            Diagram=Clones_D(obj.Mod);
            Diagram.D=Clones_FtoD(obj.F,obj.C,obj.M);
        end
        
        function res=onePath(obj)
            res=Clones_OnePathF(obj.F,obj.K);
        end
        
    end
    
    
end
