function [ F ] = Clones_gfTm(F,C,M,r)
%Clones_gfTm Transition i->j on the diagram
%	Clones_gfTm(S,C,r)
%           F : gap-free diagram representation
%           M : number of customers
%           C : vector of capacities
%           r : r=[i j m] transition
%
%	[D] = Clones_gtTm(K,M) 
%           F : gap-free transition 
%
%	See also :
%               Clones_gfT(D,C,[i j])

% C. Rovetta
% 15.04.2015
% Version 2.0
%

i=r(1);
j=r(2);
e=r(3);

K=size(C,2);

Vk=ones(K,1)+C';
Vk=[0;cumsum(Vk)];

if(i<j)
    
    Nij=C(i:j)';
    Nij=Nij+1;
    Nij=cumsum(Nij,1);
    Nij=[0;Nij];
    
    % ==== Step 1 : find subset
    
    X=F(Vk(i)+1:Vk(j+1),:);
    
    % Matrix i
    Xk=X(1:Nij(2),:);
    
    % Empty
    Xke=Xk;
    Xke(e+1:end,:)=-1;
    
    Xe=Clones_FindPath1(Nij,X,Xke );
    
    % Non Empty
    Xkne=Xk;
    Xkne(1:e,:)=-1;
    Xne=Clones_FindPath1(Nij,X,Xkne );
    
    Xtransit=Xne;
     
    if(C(j)<M)
        
        % Matrix j
        Xk=X(Nij(end-1)+1:Nij(end),:);
         
        % Full
        Xkf=Xk;
        Xkf(1:end-1,:)=-1;
        Xf=Clones_FindPath2(Nij,X,Xkf);
        
        % Non Full
        Xknf=Xk;
        Xknf(end,:)=-1;
        Xnf=Clones_FindPath2(Nij,X,Xknf);
        
        % Transit = Non Full AND Non Empty
        Xtransit=Clones_andF(Xne,Xnf);
        Xe=Clones_orF(Xe,Xf);
        
    end
    
    % ==== Step 2 : compute Transit '
  
    % Column i
    Xk=Xtransit(1:Nij(2),:);
    Xk=Clones_moveF(Xk,-1,0);
    Xtransit(1:Nij(2),:)=Xk;
    
    % k where : i< k <j
    n=2;
    for k=i+1:j-1
        
        Xk=Xtransit(Nij(n)+1:Nij(n+1),:);
        Xk=Clones_moveF(Xk,-1,1);
        Xtransit(Nij(n)+1:Nij(n+1),:)=Xk;
        
        n=n+1;
    end
    
    % Column j
    Xk=Xtransit(Nij(end-1)+1:Nij(end),:);
    Xk=Clones_moveF(Xk,0,1);
    Xtransit(Nij(end-1)+1:Nij(end),:)=Xk;
    
    % ==== Step 3 : compute A=Empty+Full+Transit '
    F(Vk(i)+1:Vk(j+1),:)=Clones_orF(Xe,Xtransit);
    
end


if(i>j)
    
    Nij=C(j:i)';
    Nij=Nij+1;
    Nij=cumsum(Nij,1);
    Nij=[0;Nij];
    
    % ==== Step 1 : find subset
    X=F(Vk(j)+1:Vk(i+1),:);
    
    % Matrix i
    Xk=X(Nij(end-1)+1:Nij(end),:);
   
    % Empty
    Xke=Xk;
    Xke(e+1:end,:)=-1;
    Xe=Clones_FindPath2(Nij,X,Xke );
    
    % Non Empty
    Xkne=Xk;
    Xkne(1:e,:)=-1;
    Xne=Clones_FindPath2(Nij,X,Xkne );
    
    Xtransit=Xne;
     
    if(C(j)<M)
        
        % Matrix j
        Xk=X(1:Nij(2),:);
         
        % Full
        Xkf=Xk;
        Xkf(1:end-1,:)=-1;
        Xf=Clones_FindPath1(Nij,X,Xkf);
        
        % Non Full
        Xknf=Xk;
        Xknf(end,:)=-1;
        Xnf=Clones_FindPath1(Nij,X,Xknf);
        
        % Transit = Non Full AND Non Empty
        Xtransit=Clones_andF(Xne,Xnf);
        Xe=Clones_orF(Xe,Xf);
        
    end
    
    % ==== Step 2 : compute Transit '
  
    % Column i
    Xk=Xtransit(Nij(end-1)+1:Nij(end),:);
    Xk=Clones_moveF(Xk,0,-1);
    Xtransit(Nij(end-1)+1:Nij(end),:)=Xk;
    
    % k where : i< k <j
    n=2;
    for k=j+1:i-1
        
        Xk=Xtransit(Nij(n)+1:Nij(n+1),:);
        Xk=Clones_moveF(Xk,1,-1);
        Xtransit(Nij(n)+1:Nij(n+1),:)=Xk;
        
        n=n+1;
    end
    
    % Column j
    Xk=Xtransit(1:Nij(2),:);
    Xk=Clones_moveF(Xk,1,0);
    Xtransit(1:Nij(2),:)=Xk;
    
    % ==== Step 3 : compute A=Empty+Full+Transit '
    F(Vk(j)+1:Vk(i+1),:)=Clones_orF(Xe,Xtransit);
    
end

end

