classdef Clones_Model
%Clones_Model Class of parameters
%           K : Queues number
%           M : Customers number
%           C : Vector of capacities
%           E : Vector of number of server
%           PP : Routing probability
%           Nuu : Service rate probability
%
%
% C. Rovetta
% 06.04.2015
% Version 2.0
%

    
    properties
        
        Name % Name of model
        M % Number of customers 
        C % Vector of capacities
        K % Number of queues
        E % Vector of number od server
        P % Routing matrix
        Mu % Vector of service rate (one server)
        Nu % Vector of global service rate (normalized)
        
        PP % Cumsum of P
        Nuu % Cumsum of Nu
        
    end
    
    methods
        function obj = Clones_Model(name,c,e,mu,p,m)
            
            % Parameters
            obj.Name=name;
            obj.M=m;
            obj.C=c;
            obj.E=e;
            obj.Mu=mu;
            obj.P=p;
            
            nu=e.*mu;
            snu=sum(nu);
            obj.Nu=nu./snu;
            obj.K=size(c,2);
            
            obj.PP=cumsum(p,2);
            obj.Nuu=cumsum(obj.Nu,2);
        end
        
        function print(obj)
            X = ['Parameter of model ',obj.Name,': '];
            disp(X);
            X = ['K=',num2str(obj.K)];
            disp(X);
            X = ['M=',num2str(obj.M)];
            disp(X);
            disp('C=');
            disp(obj.C);
            disp('E=');
            disp(obj.E);
            disp('Mu=');
            disp(obj.Mu);
            disp('Nu=');
            disp(obj.Nu);
            disp('P=');
            disp(obj.P);
            
        end
        
        % Perfect sampling
        
        function X=PSS(obj,nb)
            States=Clones_S(obj);
            X=Clones_PSS(States,nb);
        end
        
        function X=PSD(obj,nb)
            Diagram=Clones_D(obj);
            X=Clones_PSD(Diagram,nb);
        end
        
        function X=PSF(obj,nb)
            GapFree=Clones_F(obj);
            X=Clones_PSF(GapFree,nb);
        end
        
    end
    
    
end
